#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jul 13 15:40:58 2020
Max Thomas

Plot figures and output key numbers for:
    Stratospheric carbon isotope fractionation and tropospheric histories of 
    CFC-11, CFC-12 and CFC-113 isotopologues
Submitted to ACP on ?!/07/2020

Figures:
    1)  del(37Cl) profiles and m/z105->101 correction
    2)  CFC-11, -12, and -113 del(13C) firn profiles
    3)  Stratospheric Rayleigh plots for CFC-12 and -113
    4)  Tropospheric del_T(13C) for CFC-11, -12, and -113
    A1) Dilution series for CFC-11, -12, and -113 for methods A and B 
    A2) c(CH3Cl)/c(CFC-12) timeseries
    A3) Stratospheric Rayleigh plots for CFC-11
"""

# import packages
import numpy as np
import matplotlib.pyplot as plt
import pandas as pd
import statsmodels.api as sm
from statsmodels.stats.outliers_influence import summary_table


plt.close('all')
plt.rc('text', usetex=True)

data_sheets = '../Data/data_summary.xls'

# User defined plot formats [edge colour, marker, legend entry, face colour]
plotFormats = {'Dilution':['b','+','Dilution series'],\
               'NEEM09':  ['salmon','o','NEEM 2009','r'],\
               'Z13':     ['c','o','Zuiderweg et al. (2013)','c'],\
               'NEEM08':  ['salmon','o','NEEM 2008','w'],\
               'Kiruna':  ['g','.','Kiruna','g'],\
               'Gap':     ['g','x','Gap','g'],\
               'Allin':   ['k','2','$\delta(^{37}$Cl), Allin et al. (2015)','k'],\
               'Matrai':  ['k','s','$2c$','k']}

peakLimits = {'MethodA': [39000,57000,44000], \
              'MethodB': [0, 0, 300000]}
lim102 = pd.DataFrame(data=peakLimits,index=[11,12,113])
strat_inc = 2 # 0=high and mid lat, 1=high lat, 2=mid lat


test_final = 'CFC' # monte carlo loess prefix
Nitr = 200 # iterations in monte carlos

fig_size_1col_tall = (8.3/2.2,16.6/2.2)
fig_size_1col_short = (8.3/2.2,12.4/2.2)
fig_size_2col = (16/2.2,19/2.2)
fig_size_2col_narrow = (12.4/2.2,19/2.2)
fig_size_box  = (8.3/2.2,8.3/2.2)


#####################################################
#####################################################
# import data
#####################################################
#####################################################

# stratospheric data
STRAT_KIR   = pd.read_excel(data_sheets,sheet_name='Stratosphere_Kiruna',\
                         index_col=None,header=0)
STRAT_GAP   = pd.read_excel(data_sheets,sheet_name='Stratosphere_Gap',\
                         index_col=None,header=0)

# hitsories for CH3Cl and CFC-12
BUTLER = pd.read_excel(data_sheets,sheet_name='Butler_et_al_1999',usecols="A,B,C,D",\
             names = ["year_F12", "F12","year_CH3Cl","CH3Cl"])
yCH3Cl = pd.read_excel(data_sheets,sheet_name='CH3Cl_history',skiprows=3,usecols="B,C,F",
             names = ["year","datestr","conc"])
yCFC12 = pd.read_excel(data_sheets,sheet_name='F12_history',skiprows=3,usecols="A,B,C",
             names = ["year","month","conc"])

# Matrai modelling
Mat_NM09_12  = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="B,E",
              names = ["depth","correction"])
Mat_NM09_11  = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="H,K",
              names = ["depth","correction"])
Mat_NM09_113 = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="Q,N",
              names = ["depth","correction"])

Mat_NM08_12  = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="T,W",
              names = ["depth","correction"])
Mat_NM08_11  = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="Z,AC",
              names = ["depth","correction"])
Mat_NM08_113 = pd.read_excel(data_sheets,sheet_name='Martinerie',skiprows=0,usecols="AF,AI",
              names = ["depth","correction"])


# dilution series
NEEM_DIL   = pd.read_excel(data_sheets,sheet_name='Dilutions_methodB',\
                         index_col=None,header=0)
STRAT_DIL  = pd.read_excel(data_sheets,sheet_name='Dilutions_methodA',\
                         index_col=None,header=0)
NMDILplot = pd.read_excel(data_sheets,sheet_name='Firn_summary',\
                        index_col=None,usecols="B,D,E,H,I,N,O",header=1,\
                        names = ['sample','area11','del11','area12','del12','area113','del113'])
    

Z13_TRP    = pd.read_excel(data_sheets,sheet_name='Zuiderweg_et_al_2013',\
                         index_col=None,header=2,nrows=11)

# Allin et al 2015 d37Cl measurements
Allin_d37  = pd.read_excel(data_sheets,sheet_name='Allin_et_al',skiprows=32,usecols="B,C,D,E",
              names = ["depth","F11","F12","F113"])

# Load data
loessFirn_data = '../Data/Loess_output/'

# Firn data
CFC11 = pd.read_csv(loessFirn_data+test_final+'11_'+str(Nitr)+'.csv', index_col=0)
CFC12 = pd.read_csv(loessFirn_data+test_final+'12_'+str(Nitr)+'.csv', index_col=0)
CFC113 = pd.read_csv(loessFirn_data+test_final+'113_'+str(Nitr)+'.csv', index_col=0)
Z1312 = pd.read_csv(loessFirn_data+test_final+'Z13.csv', index_col=0)

# firn loess
firn11 = pd.read_csv(loessFirn_data+test_final+'Stats11_firn_'+str(Nitr)+'.csv')
firn12 = pd.read_csv(loessFirn_data+test_final+'Stats12_firn_'+str(Nitr)+'.csv')
firn113 = pd.read_csv(loessFirn_data+test_final+'Stats113_firn_'+str(Nitr)+'.csv')
firn12V = pd.read_csv(loessFirn_data+test_final+'Stats12_firn_VPDB_'+str(Nitr)+'.csv')

# troposphere loess
trop11 = pd.read_csv(loessFirn_data+test_final+'Stats11_trop_'+str(Nitr)+'.csv')
trop12 = pd.read_csv(loessFirn_data+test_final+'Stats12_trop_'+str(Nitr)+'.csv')
trop113 = pd.read_csv(loessFirn_data+test_final+'Stats113_trop_'+str(Nitr)+'.csv')
trop12V = pd.read_csv(loessFirn_data+test_final+'Stats12_trop_VPDB_'+str(Nitr)+'.csv')



MDL_12_high = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat',\
                         index_col=None,usecols="A,C,I,J,M,S,T",skiprows=2,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])
    
MDL_11_high = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat',\
                         index_col=None,usecols="A,W,AC,AD,AG,AM,AN",skiprows=11,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])
    
MDL_mn_high = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat',\
                         index_col=None,usecols="A,AQ,AW,AX,BA,BG,BH",skiprows=11,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])
    
MDL_113_high = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat',\
                         index_col=None,usecols="A,BK,BQ,BR,BU,CA,CB",skiprows=27,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])
    
MDL_11_highr = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat_F11rescale',\
                         index_col=None,usecols="A,W,AC,AD,AG,AM,AN",skiprows=11,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])
    
MDL_mn_highr = pd.read_excel(data_sheets,sheet_name='Kaiser_model_highLat_F11rescale',\
                         index_col=None,usecols="A,AQ,AW,AX,BA,BG,BH",skiprows=11,\
                         names = ["Date","A37","App","AppSig","H37","Holt","HoltSig"])

# Zuiderweg et al 2013 reconstruction span
z13_age = np.arange(1934,2009 )
      
#####################################################
#####################################################
# Plotting functions
#####################################################
#####################################################   


plotFormats = {'Dilution':['b','o','Dilution series'],\
               'NEEM09':  ['k','1','NEEM 2009','r'],\
               'Z13':     ['r','1','Zuiderweg et al., NEEM 2009','c'],\
               'NEEM08':  ['k','2','NEEM 2008','w'],\
               'Kiruna':  ['g','.','Kiruna','g'],\
               'Gap':     ['g','x','Gap','g'],\
               'Allin':   ['k','2','Allin et al. (2015)','k'],\
               'Matrai':  ['k','s','2$c$','k']}
    

def plot_neem_firn(data,handle,firn0_Trop1,vpdb,leg_ent):
    ls = data['campaign']==1
    pf8 = plotFormats['NEEM08']
    pf9 = plotFormats['NEEM09']
    x9 = data['age'][ls==1]
    x8 = data['age'][ls==0]
    if firn0_Trop1==0:
        if vpdb==0:
            y9 = data['del_firn'][ls==1]
            y8 = data['del_firn'][ls==0]
        elif vpdb==1:
            y9 = data['del_firn_vpdb'][ls==1]
            y8 = data['del_firn_vpdb'][ls==0]
    elif firn0_Trop1==1:
        if vpdb==0:
            y9 = data['del_trop'][ls==1]
            y8 = data['del_trop'][ls==0]
        elif vpdb==1:
            y9 = data['del_trop_vpdb'][ls==1]
            y8 = data['del_trop_vpdb'][ls==0]   
            
    if leg_ent==1:
        handle.plot(x8,y8,pf8[0]+pf8[1],label='This study, NEEM 2008')
        handle.plot(x9,y9,pf9[0]+pf9[1],label='This study, NEEM 2009')
    elif leg_ent==0:
        handle.plot(x8,y8,pf8[0]+pf8[1])
        handle.plot(x9,y9,pf9[0]+pf9[1])

# plot2 plots the loess with 2sigma confidence intervals
def plot_lw(stats,handle,colour,line,label,Nitr):
    handle.plot(stats['x'],stats['y'],colour+line,label=label)
    handle.fill_between(stats['x'], 
                        stats['y'] - 1.96*stats['se']*np.sqrt(Nitr), 
                        stats['y'] + 1.96*stats['se']*np.sqrt(Nitr),
                        color = colour, alpha = 0.3)
    
def plot_mdl(data,handle,vpdb,line,fill,col,label):
    m_mean = []
    for ix in data.index:
        m_mean = np.append(m_mean,\
                         (conv_05toVPDB(data['App'][ix],vpdb*del05toVPDB) + \
                          conv_05toVPDB(data['Holt'][ix],vpdb*del05toVPDB))/2)

    handle.plot(data['Date'],m_mean,line,color=col,label=label) 
        
    if fill==1:
        handle.fill_between(data['Date'],conv_05toVPDB(data['App'],vpdb*del05toVPDB)+data['AppSig']*2\
                    ,conv_05toVPDB(data['App'],vpdb*del05toVPDB)-data['AppSig']*2,color=col,alpha=0.3)    
        handle.fill_between(data['Date'],conv_05toVPDB(data['Holt'],vpdb*del05toVPDB)+data['HoltSig']*2\
                    ,conv_05toVPDB(data['Holt'],vpdb*del05toVPDB)-data['HoltSig']*2,color=col,alpha=0.15)    

def z13_trop(x_in):
    xinp = x_in - 1933.5
    x_out = \
        -265.4280 + 4.8315*xinp + (7.8555*10**-5)*xinp**2 - (3.3070*10**-4)*xinp**3
    return x_out


def strat_xy(campaign,cfc_n):
    sela = 'area102_'+str(cfc_n) 
    selx = 'Frf_'+str(cfc_n) 
    sely = 'delta_'+str(cfc_n) 
    ls = campaign[sela]>lim102.MethodA[cfc_n]
    xvar = np.log(1-campaign[selx][ls])
    yvar = np.log(1+campaign[sely][ls]/1000)*1000
    return xvar,yvar

def plot_ols(xin,mdlin,color_inp,high_low,ax):
    minx = np.min(xin[:,1])
    maxx = np.max(xin[:,1])
    xplot = np.array([minx,maxx])
    sum_tab, mdl_data, columns = summary_table(mdlin,alpha=0.05)
    ciDn, ciUp = mdl_data[:,4:6].T
    if high_low==1:
        str_ep = 'Kiruna: $\epsilon_\mathrm{app}$ = (' + np.str(np.round(mdlin.params[1],1)) + ' $\pm$ ' + np.str(np.round(mdlin.bse[1],1)) + ') ‰'
        ax.plot(xplot,mdlin.params[0] + xplot*mdlin.params[1],color_inp+'--',label = str_ep)
    else:
        str_ep = 'Gap: $\epsilon_\mathrm{app}$ = (' + np.str(np.round(mdlin.params[1],1)) + ' $\pm$ ' + np.str(np.round(mdlin.bse[1],1)) + ') ‰'
        ax.plot(xplot,mdlin.params[0] + xplot*mdlin.params[1],color_inp+'-',label = str_ep)
    order = np.argsort(xin[:,1])
    ax.fill_between(xin[order,1],ciDn[order],ciUp[order],facecolor=color_inp, alpha=0.1)
    # plt.plot(xin[order],pred_mean_ciDn[order],'g:')   
    # plt.plot(xin[order],pred_mean_ciUp[order],'g:')   
    
# back out del(13C, 2005/VPDB)
del05toVPDB = (CFC12['del_firn'][0]-CFC12['del_firn_vpdb'][0])/(CFC12['del_firn'][0]/1000 + 1)
def conv_05toVPDB(del05,del_c):
    del_v = del05*(1-del_c/1000) - del_c
    return del_v

figcount = -1   
#####################################################
#####################################################
# Figure 1: Plot 102 -> 101 correction
#####################################################
#####################################################
figcount += 1
plt.figure(num=figcount,figsize=fig_size_1col_tall,dpi=600)
plt.subplot(3,1,1)
plt.scatter(Allin_d37.depth,Allin_d37.F11,\
            c=plotFormats['Allin'][0],\
            marker=plotFormats['Allin'][1]).set_label(plotFormats['Allin'][2])
plt.scatter(Mat_NM09_11.depth,2*Mat_NM09_11.correction,\
            c=plotFormats['Matrai'][0],\
            marker=plotFormats['Matrai'][1]).set_label(plotFormats['Matrai'][2])
plt.ylabel('$\delta$(sample vs AAL) / ‰')
plt.legend(title='CFC-11',fontsize=6)

plt.subplot(3,1,2)
plt.scatter(Allin_d37.depth,Allin_d37.F12,\
            c=plotFormats['Allin'][0],\
            marker=plotFormats['Allin'][1]).set_label('')
plt.scatter(Mat_NM09_12.depth,2*Mat_NM09_12.correction,\
            c=plotFormats['Matrai'][0],\
            marker=plotFormats['Matrai'][1]).set_label('')
plt.ylabel('$\delta$(sample vs AAL) / ‰')
plt.legend(title='CFC-12')

plt.subplot(3,1,3)
plt.scatter(Allin_d37.depth,Allin_d37.F113,\
            c=plotFormats['Allin'][0],\
            marker=plotFormats['Allin'][1]).set_label('')
plt.scatter(Mat_NM09_113.depth,2*Mat_NM09_113.correction,\
            c=plotFormats['Matrai'][0],\
            marker=plotFormats['Matrai'][1]).set_label('')
plt.ylabel('$\delta$(sample vs AAL) / ‰')
plt.xlabel('depth / m')
plt.legend(title='CFC-113')
 
plt.savefig('corrections.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)


#####################################################
#####################################################
# Figure 2: Plot firn profiles
#####################################################
#####################################################
frn_fig, (frn_ax1, frn_ax2, frn_ax3) = plt.subplots(3,1,dpi=600,figsize=fig_size_1col_tall,gridspec_kw={'height_ratios': [1,2,1]})

plot_neem_firn(CFC11, frn_ax1, 0, 0, 0)
plot_neem_firn(CFC12, frn_ax2, 0, 1, 1)
plot_neem_firn(CFC113, frn_ax3, 0, 0, 0)

plot_lw(firn11,frn_ax1,plotFormats['NEEM08'][0],'-','',Nitr)
plot_lw(firn12V,frn_ax2,plotFormats['NEEM08'][0],'-','',Nitr)
plot_lw(firn113,frn_ax3,plotFormats['NEEM08'][0],'-','',Nitr)

frn_ax2.plot(Z1312['age'],Z1312['Measurement1'],plotFormats['Z13'][0]+plotFormats['Z13'][1],label=plotFormats['Z13'][2])
frn_ax2.plot(Z1312['age'],Z1312['Measurement2'],plotFormats['Z13'][0]+plotFormats['Z13'][1])

frn_ax1.legend(title='CFC-11',loc='lower right',fontsize=8)
frn_ax2.legend(title='CFC-12',loc='lower right',fontsize=8)
frn_ax3.legend(title='CFC-113',loc='lower right',fontsize=8)


frn_ax1.set_xlim([1950, 2010])
frn_ax1.set_xticklabels('')
frn_ax1.set_ylabel(u'$\delta(^{13}$C, sample vs AAL) / ‰')

frn_ax2.set_xlim([1950, 2010])
frn_ax2.set_xticklabels('')
frn_ax2.set_ylabel(u'$\delta(^{13}$C, sample vs VPDB) / ‰')

frn_ax3.set_xlim([1950, 2010])
frn_ax3.set_xlabel('Date')
frn_ax3.set_ylabel(u'$\delta(^{13}$C, sample vs AAL) / ‰')

frn_ax2.set_ylim([-90,-35])

frn_fig.tight_layout()


xlims = [1937,2050]

plt.savefig('firn.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)

#####################################################
#####################################################
# Figure 3: Plot stratospheric Rayleigh plots
#####################################################
#####################################################

ebar_size11 = 2.4
ebar_size12 = 5.7
ebar_size113 = 5.5

srt_fig, (srt_ax1, srt_ax2) = plt.subplots(2,1,dpi=600,figsize=fig_size_1col_tall)


kirx, kiry = strat_xy(STRAT_KIR,12)
srt_ax1.scatter(kirx,kiry,\
            c=plotFormats['Kiruna'][0],marker=plotFormats['Kiruna'][1],\
            ).set_label(plotFormats['Kiruna'][2])
gapx, gapy = strat_xy(STRAT_GAP,12)
srt_ax1.scatter(gapx,gapy,\
            c=plotFormats['Gap'][0],marker=plotFormats['Gap'][1],\
            ).set_label(plotFormats['Gap'][2])
strat12x_high = sm.add_constant(np.asarray(kirx))
strat12y_high = np.asarray(kiry)
strat12x_mid  = sm.add_constant(np.asarray(gapx))
strat12y_mid  = np.asarray(gapy)
mdl12_high = sm.OLS(strat12y_high,strat12x_high)
mdl12_mid  = sm.OLS(strat12y_mid,strat12x_mid)
results_high = mdl12_high.fit() 
results_mid  = mdl12_mid.fit() 
srt_ax1.errorbar(-1.6, -5, yerr=ebar_size12,fmt=plotFormats['Kiruna'][0], capsize=5)
plot_ols(strat12x_high,results_high,plotFormats['Kiruna'][0],1,srt_ax1)
plot_ols(strat12x_mid,results_mid,plotFormats['Gap'][0],0,srt_ax1)
srt_ax1.legend(title='CFC-12',fontsize=6,ncol=2)
srt_ax1.set_ylabel('ln(1+$\delta(^{13}$C, sample vs AAL)) / ‰')
#plt.xlabel('ln$(1-F_{rf})$')    
srt_ax1.set_xlim([-1.65,0.3])
srt_ax1.set_ylim(-15,50)

kirx, kiry = strat_xy(STRAT_KIR,113)
srt_ax2.scatter(kirx,kiry,\
            c=plotFormats['Kiruna'][0],marker=plotFormats['Kiruna'][1],\
            ).set_label(plotFormats['Kiruna'][2])
gapx, gapy = strat_xy(STRAT_GAP,113)
srt_ax2.scatter(gapx,gapy,\
            c=plotFormats['Gap'][0],marker=plotFormats['Gap'][1],\
            ).set_label(plotFormats['Gap'][2])
strat113x_high = sm.add_constant(np.asarray(kirx))
strat113y_high = np.asarray(kiry)
strat113x_mid  = sm.add_constant(np.asarray(gapx))
strat113y_mid  = np.asarray(gapy)
mdl113_high = sm.OLS(strat113y_high,strat113x_high)
mdl113_mid  = sm.OLS(strat113y_mid,strat113x_mid)
results_high = mdl113_high.fit() 
results_mid  = mdl113_mid.fit() 
srt_ax2.errorbar(-1.6, -5, yerr=ebar_size113,fmt=plotFormats['Kiruna'][0], capsize=5)
plot_ols(strat113x_high,results_high,plotFormats['Kiruna'][0],1,srt_ax2)
plot_ols(strat113x_mid,results_mid,plotFormats['Gap'][0],0,srt_ax2)
srt_ax2.legend(title='CFC-113',fontsize=6,ncol=2)
srt_ax2.set_ylabel('ln(1+$\delta(^{13}$C, sample vs AAL)) / ‰')
srt_ax2.set_xlabel('ln$(1-f)$')    
srt_ax2.set_xlim([-1.65,0.3])
srt_ax2.set_ylim(-15,40)

plt.savefig('stratosphere.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)

#####################################################
#####################################################
# Figure 4: Plot tropospheric histories
#####################################################
#####################################################

trp_fig, trp_ax = plt.subplots(3,1,dpi=600,figsize=fig_size_2col_narrow,gridspec_kw={'height_ratios': [1,2,1]})

# trp_ax1,trp_ax2,trp_ax3,trp_ax4,trp_ax5,trp_ax6 = trp_ax.flatten()
trp_ax1,trp_ax3,trp_ax5 = trp_ax.flatten()

z13_trop_trend = z13_trop(z13_age)

plot_neem_firn(CFC11, trp_ax1, 1, 0, 1)
plot_neem_firn(CFC12, trp_ax3, 1, 1, 0)
plot_neem_firn(CFC113, trp_ax5, 1, 0, 0)


plot_lw(trop11,trp_ax1,plotFormats['NEEM08'][0],'-','',Nitr)
plot_lw(trop12V,trp_ax3,plotFormats['NEEM08'][0],'-','',Nitr)
plot_lw(trop113,trp_ax5,plotFormats['NEEM08'][0],'-','',Nitr)


trp_ax3.plot(z13_age,z13_trop_trend,plotFormats['Z13'][0],label='Zuiderweg et al., troposphere')

plot_mdl(MDL_11_highr,trp_ax1,0,'-',1,'c','Model V\&D')
plot_mdl(MDL_mn_highr,trp_ax1,0,':',0,'c','Model M18')
plot_mdl(MDL_12_high,trp_ax3,1,'-',1,'c',None)
plot_mdl(MDL_113_high,trp_ax5,0,'-',1,'c',None)

trp_ax1.legend(title='CFC-11',loc='upper left',fontsize=6)
trp_ax3.legend(title='CFC-12',loc='upper left',fontsize=6)
trp_ax5.legend(title='CFC-113',loc='upper left',fontsize=6)


trp_ax1.set_xlim(xlims)
trp_ax1.set_xticklabels('')
trp_ax1.set_xticks([1940,1960,1980,2000,2020,2040])
trp_ax1.set_ylabel(u'$\delta(^{13}$C sample vs AAL) / ‰')


trp_ax1.set_ylim([-12,10])

trp_ax3.set_xlim(xlims)
trp_ax3.set_xticklabels('')
trp_ax3.set_ylabel(u'$\delta(^{13}$C sample vs VPDB) / ‰')
trp_ax3.set_xticks([1940,1960,1980,2000,2020,2040])

trp_ax3.set_ylim([-90,-30])

trp_ax5.set_xlim(xlims)
trp_ax5.set_xlabel('Date')
trp_ax5.set_ylabel(u'$\delta(^{13}$C sample vs AAL) / ‰')
trp_ax5.set_xticks([1940,1960,1980,2000,2020,2040])


trp_ax5.set_ylim([-15,10])






trp_fig.tight_layout()

plt.savefig('troposphere.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)

#####################################################
#####################################################
# Figure A1: Plot dilution series for stratospheic data
#####################################################
#####################################################

#Stratosphere
figcount += 1
plt.figure(figsize=fig_size_2col,dpi=600)
plt.subplot(3,2,1)
plt.scatter(STRAT_DIL.area102_11,STRAT_DIL.delta_11,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label(plotFormats['Dilution'][2])
plt.scatter(STRAT_KIR.area102_11,STRAT_KIR.delta_11,\
            c=plotFormats['Kiruna'][0],\
            marker=plotFormats['Kiruna'][1]).set_label(plotFormats['Kiruna'][2])
plt.scatter(STRAT_GAP.area102_11,STRAT_GAP.delta_11,\
            c=plotFormats['Gap'][0],\
            marker=plotFormats['Gap'][1]).set_label(plotFormats['Gap'][2])
plt.legend(title='CFC-11')
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.plot(np.array([lim102.MethodA[11],lim102.MethodA[11]]),np.array([-300,300]),'r:')
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.xlim([0,500000])
plt.ylim([-100,230])
plt.ylabel('$\delta(^{13}$C$)$ / ‰')

plt.subplot(3,2,3)
plt.scatter(STRAT_DIL.area102_12,STRAT_DIL.delta_12,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label(plotFormats['Dilution'][2])
plt.scatter(STRAT_KIR.area102_12,STRAT_KIR.delta_12,\
            c=plotFormats['Kiruna'][0],\
            marker=plotFormats['Kiruna'][1]).set_label(plotFormats['Kiruna'][2])
plt.scatter(STRAT_GAP.area102_12,STRAT_GAP.delta_12,\
            c=plotFormats['Gap'][0],\
            marker=plotFormats['Gap'][1]).set_label(plotFormats['Gap'][2])
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.plot(np.array([lim102.MethodA[12],lim102.MethodA[12]]),np.array([-300,300]),'r:')
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.xlim([0,400000])
plt.ylim([-80,100])
plt.ylabel('$\delta(^{13}$C$)$ / ‰')
plt.legend(title='CFC-12')

plt.subplot(3,2,5)
plt.scatter(STRAT_DIL.area102_113,STRAT_DIL.delta_113,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label(plotFormats['Dilution'][2])
plt.scatter(STRAT_KIR.area102_113,STRAT_KIR.delta_113,\
            c=plotFormats['Kiruna'][0],\
            marker=plotFormats['Kiruna'][1]).set_label(plotFormats['Kiruna'][2])
plt.scatter(STRAT_GAP.area102_113,STRAT_GAP.delta_113,\
            c=plotFormats['Gap'][0],\
            marker=plotFormats['Gap'][1]).set_label(plotFormats['Gap'][2])
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.plot(np.array([lim102.MethodA[113],lim102.MethodA[113]]),np.array([-300,300]),'r:')
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.xlim([0,500000])
plt.ylim([-70,120])
plt.xlabel('102 peak area')
plt.ylabel('$\delta(^{13}$C$)$ / ‰')
plt.legend(title='CFC-113')


#####################################################
#####################################################
# Plot dilution series for NEEM firn
#####################################################
#####################################################
#figcount += 1
#plt.figure(num=figcount,figsize=(12/2.2,21/2.2),dpi=600)
NM09_sel = []
for ir in NMDILplot.index:
    NM09_sel = np.append(NM09_sel,'2009' in NMDILplot['sample'][ir])
NM09_sel = NM09_sel.astype(bool)

plt.subplot(3,2,2)
plt.scatter(NEEM_DIL.area102_11,NEEM_DIL.delta_11,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label(plotFormats['Dilution'][2])

plt.scatter(NMDILplot['area11'][NM09_sel],NMDILplot['del11'][NM09_sel],\
            c=plotFormats['NEEM09'][0],\
            marker=plotFormats['NEEM09'][1]).set_label(plotFormats['NEEM09'][2])
    
plt.scatter(NMDILplot['area11'][~NM09_sel],NMDILplot['del11'][~NM09_sel],\
            c=plotFormats['NEEM08'][0],\
            marker=plotFormats['NEEM08'][1]).set_label(plotFormats['NEEM08'][2])
    

plt.legend(title='CFC-11')
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.xlim([0,0.8*10**7])

plt.subplot(3,2,4)
plt.scatter(NEEM_DIL.area102_12,NEEM_DIL.delta_12,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label('')

plt.scatter(NMDILplot['area12'][NM09_sel],NMDILplot['del12'][NM09_sel],\
            c=plotFormats['NEEM09'][0],\
            marker=plotFormats['NEEM09'][1]).set_label('')
    
plt.scatter(NMDILplot['area12'][~NM09_sel],NMDILplot['del12'][~NM09_sel],\
            c=plotFormats['NEEM08'][0],\
            marker=plotFormats['NEEM08'][1]).set_label('')
  
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.xlim([0,0.175*10**7])
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.legend(title='CFC-12',fontsize=6)

plt.subplot(3,2,6)
plt.scatter(NEEM_DIL.area102_113,NEEM_DIL.delta_113,\
            c=plotFormats['Dilution'][0],\
            marker=plotFormats['Dilution'][1]).set_label('')

plt.scatter(NMDILplot['area113'][NM09_sel],NMDILplot['del113'][NM09_sel],\
            c=plotFormats['NEEM09'][0],\
            marker=plotFormats['NEEM09'][1]).set_label('')
    
plt.scatter(NMDILplot['area113'][~NM09_sel],NMDILplot['del113'][~NM09_sel],\
            c=plotFormats['NEEM08'][0],\
            marker=plotFormats['NEEM08'][1]).set_label('')
  
plt.plot(np.array([0,16000000]),np.array([0,0]),'k:')
plt.xlim([0,0.25*10**7])
plt.xlabel('102 peak area')
plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
plt.legend(title='CFC-113')

plt.tight_layout()

plt.savefig('dilutions.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)



#####################################################
#####################################################
# Figure A2: Plot y(CFC-12) / y(CH3Cl) history
#####################################################
#####################################################

smoothN = 1
def runningMeanFast(x, N):
    return np.convolve(x, np.ones((N,))/N)[(N-1):]


CFC12_dn = yCFC12.year + (yCFC12.month-1)/12

isort = np.argsort(yCH3Cl.year)
CH3Cl_conc = [yCH3Cl.conc[isort[ix]] for ix in range(0,len(isort))]
CH3Cl_dn = [yCH3Cl.year[isort[ix]] for ix in range(0,len(isort))]
CH3Cl_conc_smoothed = runningMeanFast(CH3Cl_conc,smoothN)

temp_dn = yCH3Cl.year*0
temp_month_average = yCH3Cl.year*0
CH3Cl_month = yCH3Cl.year*0
CH3Cl_year = yCH3Cl.year*0
mn_past = 0
count = 0
for ix in yCH3Cl.index[0:-100]:
    rds = yCH3Cl.datestr[ix]
    yrs = rds[0:4]
    yr = int(yrs)
    CH3Cl_year[ix] = yr
    mns = rds[4]+rds[5]
    mn = int(mns)
    CH3Cl_month[ix] = mn
    temp_conc = yCH3Cl.conc[ix]
    temp_N = 1
    if not(mn==mn_past):
        count = count + 1
        mnplus = yCH3Cl.datestr[ix+temp_N]
        mnplus = mnplus[4] + mnplus[5]
        mnplus = int(mnplus)
        while mnplus==mn:
            temp_N = temp_N + 1
            temp_conc = temp_conc + yCH3Cl.conc[ix+temp_N]
            mnplus = yCH3Cl.datestr[ix+temp_N]
            mnplus = mnplus[4] + mnplus[5]
            mnplus = int(mnplus)
        temp_dn[count] = yCH3Cl.year[ix]
        temp_month_average[count] = temp_conc / temp_N
    mn_past = mn


year_av_CFC12 = yCH3Cl.year[1995:2008]*0    
year_av_CH3Cl = yCH3Cl.year[1995:2008]*0    
year_ratio = yCH3Cl.year[1995:2008]*0    
year_plot = yCH3Cl.year[1995:2008]*0    
count = 0
for year_i in range(1995,2008):
    count = count + 1
    year_plot[count] = year_i
    year_av_CFC12[count] = np.mean(yCFC12.conc[yCFC12.year==year_i])
    year_av_CH3Cl[count] = np.mean(yCH3Cl.conc[(yCH3Cl.year>year_i) & (yCH3Cl.year<(year_i+1))])
    year_ratio[count] = year_av_CFC12[count] / year_av_CH3Cl[count]
 
Bratio = []
Byear = []
for ix in BUTLER.index:
    Bratio = np.append(Bratio,BUTLER['F12'][ix] / BUTLER['CH3Cl'][ix])
    Byear = np.append(Byear,BUTLER['year_F12'][ix])

F12CH3Cl = {'year4Butler':Byear[0:-2],'ratio4Butler':Bratio[0:-2],'year4NOAA':year_plot,'ratio4NOAA':year_ratio} 

figcount += 1

ratio_fig, ax_ratio = plt.subplots(1,1,dpi=600,figsize=fig_size_box)
#plt.figure(num=figcount,figsize=(8.3/2.2,8.3/2.2),dpi=600)
#ax=plt.subplot(111)
smoothN = 1 # window to smooth CH3Cl conc
z13_samp = [1968, 1980, 1993]
labs =['69.4', '66.8', '63.8']

ax_ratio.scatter(F12CH3Cl['year4Butler'],F12CH3Cl['ratio4Butler'], facecolors='none', edgecolors='k')
ax_ratio.plot(F12CH3Cl['year4NOAA'],F12CH3Cl['ratio4NOAA'],'k.')
ax_ratio.set_ylabel("$\gamma_\mathrm{(CFC-12)} / \gamma_\mathrm{(CH_3Cl)}$")
ax_ratio.set_xlabel('Date')
ax_ratio.set_xlim([1930, 2010])
ax_ratio.set_ylim([-0.1, 1.3])
y1 = F12CH3Cl['ratio4Butler'][F12CH3Cl['year4Butler']==z13_samp[0]]
y2 = F12CH3Cl['ratio4Butler'][F12CH3Cl['year4Butler']==z13_samp[1]]
y3 = F12CH3Cl['ratio4Butler'][F12CH3Cl['year4Butler']==z13_samp[2]]
ax_ratio.annotate(labs[0]+' m',xy=(z13_samp[0],y1),xytext=(z13_samp[0]-20,y1),arrowprops=dict(arrowstyle="->", connectionstyle="arc3"))
ax_ratio.annotate(labs[1]+' m',xy=(z13_samp[1],y2),xytext=(z13_samp[1]-20,y2),arrowprops=dict(arrowstyle="->", connectionstyle="arc3"))
ax_ratio.annotate(labs[2]+' m',xy=(z13_samp[2],y3),xytext=(z13_samp[2]-20,y3),arrowprops=dict(arrowstyle="->", connectionstyle="arc3"))
ax_ratio.plot([1992, 2008],[1.05, 1.05],'k')
ax_ratio.annotate('Shallower \n depths',xy = (1994, 1.07))


plt.savefig('ch3cl.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)


#####################################################
#####################################################
# Figure A3: Plot CFC-11 stratosphere
#####################################################
#####################################################


f11_fig, f11_ax = plt.subplots(2,1,dpi=600,figsize=fig_size_1col_short,gridspec_kw={'height_ratios': [1,1]})

f11_ax1, f11_ax2 = f11_ax.flatten()


kirx, kiry = strat_xy(STRAT_KIR,11)

gapx, gapy = strat_xy(STRAT_GAP,11)


strat11x_high = sm.add_constant(np.asarray(kirx))
strat11y_high = np.asarray(kiry)
strat11x_mid  = sm.add_constant(np.asarray(gapx))
strat11y_mid  = np.asarray(gapy)
mdl11_high = sm.OLS(strat11y_high,strat11x_high)
mdl11_mid  = sm.OLS(strat11y_mid,strat11x_mid)
results_high = mdl11_high.fit() 
results_mid  = mdl11_mid.fit() 
plot_ols(strat11x_high,results_high,plotFormats['Kiruna'][0],1,f11_ax1)
plot_ols(strat11x_mid,results_mid,plotFormats['Gap'][0],0,f11_ax1)
f11_ax1.errorbar(-1.6, -5, yerr=ebar_size11,fmt=plotFormats['Kiruna'][0], capsize=5)
f11_ax1.set_xlim([-1.65,0.3])
f11_ax1.set_ylim(-15,40)
f11_ax1.set_ylabel('ln(1+$\delta(^{13}$C, sample vs AAL)) / ‰')
f11_ax1.set_xlabel('ln(1-$f$)')
#plt.xlabel('ln$(1-F_{rf})$')    
f11_ax1.scatter(kirx,kiry,\
            c=plotFormats['Kiruna'][0],marker=plotFormats['Kiruna'][1],\
            ).set_label(plotFormats['Kiruna'][2])
f11_ax1.scatter(gapx,gapy,\
            c=plotFormats['Gap'][0],marker=plotFormats['Gap'][1],\
            ).set_label(plotFormats['Gap'][2])
f11_ax1.legend(title='CFC-11',fontsize=6,ncol=2)

plot_neem_firn(CFC11, f11_ax2, 1, 0, 1)


plot_lw(trop11,f11_ax2,plotFormats['NEEM08'][0],'-','',Nitr)


plot_mdl(MDL_11_high,f11_ax2,0,'-',1,'c','Model V\&D')
plot_mdl(MDL_mn_high,f11_ax2,0,':',0,'c','Model M18')

f11_ax2.legend(title='CFC-11, $\epsilon_\mathrm{app}$(high-lat)',loc='upper left',fontsize=6)


f11_ax2.set_xlim(xlims)
f11_ax2.set_xticks([1940,1960,1980,2000,2020,2040])
f11_ax2.set_ylabel(u'$\delta(^{13}$C, sample vs AAL) / ‰')

f11_ax2.set_ylim([-15,20])

f11_ax2.set_xlabel('Date')


f11_fig.tight_layout()

plt.savefig('cfc11_appendix.png', dpi=600, facecolor='w', edgecolor='w',
        orientation='portrait', format='png',
        transparent=False, bbox_inches='tight', pad_inches=0.1,metadata=None)

######################
#### Key numbers
######################

R_eapp_11 = 7.8/2.44
R_eapp_12 = 20.2/12.2
R_eapp_113 = 9.4/3.5

def trend4paper(profile_in,Nitr):
    #trend = profile_in['y'][24] - profile_in['y'][0]
    trend = (profile_in['y'][24] - profile_in['y'][0])/(1+ profile_in['y'][0]/1000)
    date_range = (profile_in['x'][0],profile_in['x'][24])
    se1 = profile_in['se'][0] * np.sqrt(Nitr)
    seend = profile_in['se'][24] * np.sqrt(Nitr)
    setrend = np.sqrt(se1**2 + seend**2)
    mean_se = np.mean(profile_in['se']*np.sqrt(Nitr))
    return trend, date_range, setrend, mean_se

def printTrend(trend_in,cfc,firnTrop):
    str2print = cfc + ', ' + firnTrop + ': '
    print(str2print)
    print('    trend = ' + str(round(trend_in[0],1)) + ' \pm ' + str(round(trend_in[2],1)))
    print('    range = ' + str(trend_in[1]) )
    print('    mean_se = ' + str(round(trend_in[3],1)))
        
def printModelE(mdl_data,sigma,vpdb,Reapp):
    #del_E = (mdl_data['App'][0] + mdl_data['Holt'][0])/2
    ix05 = (np.abs(mdl_data['Date']-2005.5)).idxmin()
    del_E_A = -(Reapp) * mdl_data['A37'][ix05] / (1 + mdl_data['A37'][ix05]/1000) 
    del_E_H = -(Reapp) * mdl_data['H37'][ix05] / (1 + mdl_data['H37'][ix05]/1000) 
    del_E = (del_E_A + del_E_H) / 2
    range_del_E = [round(min(mdl_data['App'][0] - sigma * mdl_data['AppSig'][0],\
                       mdl_data['Holt'][0] - sigma * mdl_data['HoltSig'][0]),1),\
                   round(max(mdl_data['App'][0] + sigma * mdl_data['AppSig'][0],\
                       mdl_data['Holt'][0] + sigma * mdl_data['HoltSig'][0]),1)]
    err_mean = np.sqrt(mdl_data['AppSig'][0]**2 + mdl_data['HoltSig'][0]**2) / 2
    err_mean = err_mean * sigma
    if vpdb==1:
        del_E = conv_05toVPDB(del_E, del05toVPDB)     
        range_del_E[0] = round(conv_05toVPDB(range_del_E[0], del05toVPDB),1)        
        range_del_E[1] = round(conv_05toVPDB(range_del_E[1], del05toVPDB),1)
    return round(del_E,1), range_del_E, round(err_mean,1)


mon_diff_high = (MDL_11_highr['App'][105] + MDL_11_highr['Holt'][105])/2 - \
               (MDL_mn_highr['App'][105] + MDL_mn_highr['Holt'][105])/2

printTrend(trend4paper(firn11,Nitr),'CFC-11','firn')
printTrend(trend4paper(firn12V,Nitr),'CFC-12','firn')
printTrend(trend4paper(firn113,Nitr),'CFC-113','firn')
printTrend(trend4paper(trop11,Nitr),'CFC-11','trop')
printTrend(trend4paper(trop12V,Nitr),'CFC-12','trop')
printTrend(trend4paper(trop113,Nitr),'CFC-113','trop')

print('del_E(CFC-11, high-lat, AAL) = '+str(printModelE(MDL_11_highr,2,0,R_eapp_11)))
print('del_E(CFC-12, high-lat, AAL) = '+str(printModelE(MDL_12_high,2,0,R_eapp_12)))
print('del_E(CFC-113, high-lat, AAL) = '+str(printModelE(MDL_113_high,2,0,R_eapp_113)))

print('del_E(CFC-12, high-lat, VPDB) = '+str(printModelE(MDL_12_high,2,1,R_eapp_12)))

print('VD - M18, high-lat = ' + str(round(mon_diff_high,1)))












